==> unicore-ucc6-5.0.0-1.src.tar.gz: ucc-admin/src/main/java/de/fzj/unicore/ucc/admin/AdminServiceInfo.java <==
package de.fzj.unicore.ucc.admin;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Comparator;
import java.util.List;

import org.w3.x2005.x08.addressing.EndpointReferenceType;

import de.fzj.unicore.uas.TargetSystemFactory;
import de.fzj.unicore.ucc.actions.ListActionBase;
import de.fzj.unicore.wsrflite.xmlbeans.MetricValueDocument.MetricValue;
import de.fzj.unicore.wsrflite.xmlbeans.ServiceEntryDocument.ServiceEntry;
import de.fzj.unicore.wsrflite.xmlbeans.client.AdminServiceClient;

/**
 * lists accessible admin services and shows information
 *
 * @author schuller
 */
public class AdminServiceInfo extends ListActionBase<AdminServiceClient>{

	@Override
	public void process() {
		super.process();
		
		try{
			List<AdminServiceClient>clients=createClients();
			for(AdminServiceClient asc: clients){
				try{
				verbose("Contacting admin service at <"+asc.getUrl()+">");
				}catch(Exception ex){
					verbose("Can't access <"+asc.getUrl()+">");
					continue;
				}
				if(filterMatch(asc)){
					 try{
						 list(asc);
						 lastNumberOfResults++;
					 }catch(Exception ex){
						 error("Error showing admin service info at <"+asc.getUrl()+">",ex);
					 }
				}						
			}
		}catch(Exception ex){
			error("Error executing admin command",ex);
			endProcessing(1);
		}
	}

	protected void list(AdminServiceClient asc)throws Exception{
		message(asc.getUrl()+" "+getDetails(asc));
		printWSRFProperties(asc);
	}
	
	@Override
	protected String getDetails(AdminServiceClient asc)throws Exception{
		if(!detailed)return "";
		StringBuilder details=new StringBuilder();
		String sep=System.getProperty("line.separator");
		boolean first=true;
		for(ServiceEntry e: asc.getServiceNames()){
			if(first){
				details.append(sep).append("  Services: ");
				first=false;
			}
			details.append(sep).append("    ");
			details.append(e.getServiceName());
			if(e.getIsWSRF()){
				details.append("[").append(e.getNumberOfInstances()).append("]");
			}
		}
		first=true;
		MetricValue[] monitors=asc.getMonitorMetrics();
		Arrays.sort(monitors, new MetricSorter());
		for(MetricValue v: monitors){
			if(first){
				details.append(sep).append("  Monitors: ");
				first=false;
			}
			details.append(sep).append("    ");
			details.append(v.getName());
			details.append(": ").append(v.getValue()).append(" ").append(v.getUnits());
		}
		
		MetricValue[] allMetrics=asc.getMetrics(null,null,true);
		Arrays.sort(allMetrics, new MetricSorter());
		first=true;
		for(MetricValue v: allMetrics){
			if(first){
				details.append(sep).append("  Metrics: ");
				first=false;
			}
			details.append(sep).append("    ");
			details.append(v.getName());
			details.append(": ").append(v.getValue()).append(" ").append(v.getUnits());
		}
		
		details.append(sep).append("  Available commands: "+Arrays.asList(asc.getAvailableAdminActions()));
		return details.toString();
	}
	
	
	
	
	private List<AdminServiceClient> createClients()throws Exception{
		List<AdminServiceClient>clients=new ArrayList<AdminServiceClient>();
		List<EndpointReferenceType> urls=findURLs();
		for(EndpointReferenceType u: urls){
			AdminServiceClient asc=new AdminServiceClient(u,securityProperties);
			clients.add(asc);
		}
		return clients;
	}
	
	private List<EndpointReferenceType> findURLs()throws Exception{
		List<EndpointReferenceType>tsfs=registry.listServices(TargetSystemFactory.TSF_PORT);
		List<EndpointReferenceType>result=new ArrayList<EndpointReferenceType>();

		for(EndpointReferenceType epr: tsfs){
			String tsfURL=epr.getAddress().getStringValue();
			int endIndex=tsfURL.lastIndexOf("TargetSystemFactoryService");
			String adminServiceURL=epr.getAddress().getStringValue().substring(0, endIndex)+"AdminService?res=default_admin";
			EndpointReferenceType adminEPR=EndpointReferenceType.Factory.newInstance();
			adminEPR.addNewAddress().setStringValue(adminServiceURL);
			result.add(adminEPR);
		}
		return result;
	}
	@Override
	public String getName() {
		return "admin-info";
	}

	@Override
	public String getArgumentList() {
		return "";
	}

	@Override
	public String getSynopsis() {
		return "Displays accessible AdminService instances and some information about them.";
	}

	@Override
	public String getDescription() {
		return "Show accessible admin service instances and optionally detailed information about services";
	}

	@Override
	public String getCommandGroup() {
		return AdminCommands.CMD_GROUP;
	}

	private static class MetricSorter implements Comparator<MetricValue>{

		@Override
		public int compare(MetricValue o1, MetricValue o2) {
			if(o1 == null || o2==null )return 0;
			return o1.getName().compareTo(o2.getName());
		}
		
	}
}

==> unicore-ucc6-6.0.0-0.src.tar.gz: ucc-admin/src/main/java/de/fzj/unicore/ucc/admin/AdminServiceInfo.java <==
package de.fzj.unicore.ucc.admin;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Comparator;
import java.util.List;

import org.w3.x2005.x08.addressing.EndpointReferenceType;

import de.fzj.unicore.uas.TargetSystemFactory;
import de.fzj.unicore.ucc.actions.ListActionBase;
import de.fzj.unicore.wsrflite.xmlbeans.MetricValueDocument.MetricValue;
import de.fzj.unicore.wsrflite.xmlbeans.ServiceEntryDocument.ServiceEntry;
import de.fzj.unicore.wsrflite.xmlbeans.client.AdminServiceClient;

/**
 * lists accessible admin services and shows information
 *
 * @author schuller
 */
public class AdminServiceInfo extends ListActionBase<AdminServiceClient>{

	@Override
	public void process() {
		super.process();

		try{
			List<AdminServiceClient>clients=createClients();
			for(AdminServiceClient asc: clients){
				try{
					verbose("Contacting admin service at <"+asc.getUrl()+">");
				}catch(Exception ex){
					verbose("Can't access <"+asc.getUrl()+">");
					continue;
				}
				if(filterMatch(asc)){
					try{
						list(asc);
						lastNumberOfResults++;
					}catch(Exception ex){
						error("Error showing admin service info at <"+asc.getUrl()+">",ex);
					}
				}						
			}
		}catch(Exception ex){
			error("Error executing admin command",ex);
			endProcessing(1);
		}
	}

	protected void list(AdminServiceClient asc)throws Exception{
		message(asc.getUrl()+" "+getDetails(asc));
		printWSRFProperties(asc);
	}

	@Override
	protected String getDetails(AdminServiceClient asc)throws Exception{
		if(!detailed)return "";
		StringBuilder details=new StringBuilder();
		String sep=System.getProperty("line.separator");
		boolean first=true;
		for(ServiceEntry e: asc.getServiceNames()){
			if(first){
				details.append(sep).append("  Services: ");
				first=false;
			}
			details.append(sep).append("    ");
			details.append(e.getServiceName());
			if(e.getIsWSRF()){
				details.append("[").append(e.getNumberOfInstances()).append("]");
			}
		}
		first=true;
		MetricValue[] monitors=asc.getMonitorMetrics();
		Arrays.sort(monitors, new MetricSorter());
		for(MetricValue v: monitors){
			if(first){
				details.append(sep).append("  Monitors: ");
				first=false;
			}
			details.append(sep).append("    ");
			details.append(v.getName());
			details.append(": ").append(v.getValue()).append(" ").append(v.getUnits());
		}

		MetricValue[] allMetrics=asc.getMetrics(null,null);
		Arrays.sort(allMetrics, new MetricSorter());
		first=true;
		for(MetricValue v: allMetrics){
			if(first){
				details.append(sep).append("  Metrics: ");
				first=false;
			}
			details.append(sep).append("    ");
			details.append(v.getName());
			details.append(": ").append(v.getValue()).append(" ").append(v.getUnits());
		}

		List<AdminServiceClient.AdminAction> aCmds=asc.getAdminActions();
		if(aCmds.size()>0){
			details.append(sep).append("  Available commands:");
			for(AdminServiceClient.AdminAction aCmd: aCmds){
				details.append(sep).append("    ");
				details.append(aCmd.name);
				if(aCmd.description!=null){
					details.append(" : ").append(aCmd.description);
				}
			}
		}
		return details.toString();
	}




	private List<AdminServiceClient> createClients()throws Exception{
		List<AdminServiceClient>clients=new ArrayList<AdminServiceClient>();
		List<EndpointReferenceType> urls=findURLs();
		for(EndpointReferenceType u: urls){
			AdminServiceClient asc=new AdminServiceClient(u,securityProperties);
			clients.add(asc);
		}
		return clients;
	}

	private List<EndpointReferenceType> findURLs()throws Exception{
		List<EndpointReferenceType>tsfs=registry.listServices(TargetSystemFactory.TSF_PORT);
		List<EndpointReferenceType>result=new ArrayList<EndpointReferenceType>();

		for(EndpointReferenceType epr: tsfs){
			String tsfURL=epr.getAddress().getStringValue();
			int endIndex=tsfURL.lastIndexOf("TargetSystemFactoryService");
			String adminServiceURL=epr.getAddress().getStringValue().substring(0, endIndex)+"AdminService?res=default_admin";
			EndpointReferenceType adminEPR=EndpointReferenceType.Factory.newInstance();
			adminEPR.addNewAddress().setStringValue(adminServiceURL);
			result.add(adminEPR);
		}
		return result;
	}
	@Override
	public String getName() {
		return "admin-info";
	}

	@Override
	public String getArgumentList() {
		return "";
	}

	@Override
	public String getSynopsis() {
		return "Displays accessible AdminService instances and some information about them.";
	}

	@Override
	public String getDescription() {
		return "Show accessible admin service instances and optionally detailed information about services";
	}

	@Override
	public String getCommandGroup() {
		return AdminCommands.CMD_GROUP;
	}

	private static class MetricSorter implements Comparator<MetricValue>{

		@Override
		public int compare(MetricValue o1, MetricValue o2) {
			if(o1 == null || o2==null )return 0;
			return o1.getName().compareTo(o2.getName());
		}

	}
}
